pub async fn drop_test_databases()Expand description
Drops all registered empheral test databases This must be executed AFTER the homeserver or testnet is dropped.
pub async fn drop_test_databases()Drops all registered empheral test databases This must be executed AFTER the homeserver or testnet is dropped.