Testnet

Struct Testnet 

pub struct Testnet { /* private fields */ }
A local test network for Pubky Core development. Can create a flexible amount of pkarr relays, http relays and homeservers.

Keeps track of the components and can create new ones. Cleans up all resources when dropped.

Implementations

Source

impl Testnet

pub async fn new() -> Result<Self>

Run a new testnet with a (fully-initialized) local DHT.

pub async fn new_unseeded() -> Result<Self>

Run a new testnet with a (faster, but partially-initialized) local DHT.

pub async fn new_with_custom_postgres( postgres_connection_string: ConnectionString, ) -> Result<Self>

Run a new testnet with a local DHT. Pass an optional postgres connection string to use for the homeserver. If None, the default test connection string is used.

pub async fn create_homeserver(&mut self) -> Result<&HomeserverApp>

Run the full homeserver app with core and admin server.

Uses ConfigToml::default_test_config() which enables the admin server. Automatically listens on ephemeral ports and uses this Testnet’s bootstrap nodes and relays.

pub async fn create_random_homeserver(&mut self) -> Result<&HomeserverApp>

Run the full homeserver app with core and admin server using a freshly generated random keypair.

Uses ConfigToml::default_test_config() which enables the admin server. Automatically listens on ephemeral ports and uses this Testnet’s bootstrap nodes and relays.

pub async fn create_homeserver_app_with_mock( &mut self, mock_dir: MockDataDir, ) -> Result<&HomeserverApp>

Run the full homeserver app with core and admin server Automatically listens on the configured ports. Automatically uses the configured bootstrap nodes and relays in this Testnet.

pub async fn create_http_relay(&mut self) -> Result<&HttpRelay>

Run an HTTP Relay

pub async fn create_pkarr_relay(&mut self) -> Result<Url>

Run a new Pkarr relay.

You can access the list of relays at Self::pkarr_relays.

pub fn dht_bootstrap_nodes(&self) -> Vec<DomainPort>

Returns a list of DHT bootstrapping nodes.

pub fn dht_relay_urls(&self) -> Vec<Url>

Returns a list of pkarr relays.

pub fn client_builder(&self) -> PubkyHttpClientBuilder

Create a pubky::PubkyHttpClientBuilder and configure it to use this local test network.

pub fn client(&self) -> Result<PubkyHttpClient, BuildError>

Creates a pubky::PubkyHttpClient pre-configured to use this test network.

This is a convenience method that builds a client from Self::client_builder.

pub fn sdk(&self) -> Result<Pubky, BuildError>

Creates a pubky::Pubky SDK facade pre-configured to use this test network.

This is a convenience method that builds a client from Self::client_builder.

pub fn pkarr_client_builder(&self) -> ClientBuilder

Create a pkarr::ClientBuilder and configure it to use this local test network.