Skip to main content Crate pubky_testnet Copy item path Source pub use pubky ;pub use pubky_common ;pub use pubky_homeserver ;EphemeralTestnet A testnet for automated tests — all ports are random and all state is in-memory. EphemeralTestnetBuilder Builder for configuring and creating an EphemeralTestnet . StaticTestnet A testnet for interactive / CLI use — all ports are fixed and well-known. StaticTestnetBuilder Builder for configuring and starting a StaticTestnet . Testnet A local test network for developing Pubky homeserver or applications depending on it.
Can create a flexible amount of pkarr relays, http relays and homeservers. drop_test_databases Drops all registered empheral test databases
This must be executed AFTER the homeserver or testnet is dropped. test A macro that wraps a test function and makes sure the postgres test
database(s) are dropped after the test completes/panics.