StaticTestnet

Struct StaticTestnet 

pub struct StaticTestnet {
    pub testnet: Testnet,
    pub homeserver_config: Option<PathBuf>,
    /* private fields */
}
A simple testnet with

  • A local DHT with a boostrap node on port 6881.
  • pkarr relay on port 15411.
  • http relay on port 15412.
  • A homeserver with address is hardcoded to 8pinxxgqs41n4aididenw5apqp1urfmzdztr8jt4abrkdn435ewo.
  • An admin server for the homeserver on port 6288.

Fields

testnet: Testnet

Inner flexible testnet.

homeserver_config: Option<PathBuf>

Optional path to the homeserver config file if set.

Implementations

Source

impl StaticTestnet

pub async fn start() -> Result<Self>

Run a new static testnet with the default homeserver config.

pub async fn start_with_homeserver_config(config_path: PathBuf) -> Result<Self>

Run a new static testnet with a custom homeserver config.

pub async fn new(config_path: Option<PathBuf>) -> Result<Self>

Run a new simple testnet.

pub async fn create_random_homeserver(&mut self) -> Result<&HomeserverApp>

Create an additional homeserver with a random keypair

pub fn client_builder(&self) -> PubkyHttpClientBuilder

Create a new pubky client builder.

pub fn client(&self) -> Result<PubkyHttpClient, BuildError>

Creates a pubky::PubkyHttpClient pre-configured to use this test network.

pub fn sdk(&self) -> Result<Pubky, BuildError>

Creates a pubky::Pubky SDK facade pre-configured to use this test network.

This is a convenience method that builds a client from Self::client_builder.

pub fn pkarr_client_builder(&self) -> ClientBuilder

Create a new pkarr client builder.

pub fn homeserver_app(&self) -> &HomeserverApp

Get the homeserver in the testnet.

pub fn http_relay(&self) -> &HttpRelay

Get the http relay in the testnet.

pub fn pkarr_relay(&self) -> &Relay

Get the pkarr relay in the testnet.

pub fn bootstrap_nodes(&self) -> Vec<String>

Get the bootstrap nodes for the testnet.