Struct Testnet

pub struct Testnet { /* private fields */ }
A local test network for Pubky Core development.

Implementations

Source

impl Testnet

pub async fn run() -> Result<Self>

Run a new testnet.

pub async fn run_with_hardcoded_configurations() -> Result<Self>

Create these components with hardcoded configurations:

  1. A local DHT with bootstrapping nodes: &["localhost:6881"]
  2. A Pkarr Relay running on port 15411
  3. A Homeserver with address is hardcoded to 8pinxxgqs41n4aididenw5apqp1urfmzdztr8jt4abrkdn435ewo
  4. An HTTP relay running on port 15412
pub fn bootstrap(&self) -> &[String]

Returns a list of DHT bootstrapping nodes.

pub fn relays(&self) -> Box<[Url]>

Returns a list of pkarr relays.

pub async fn run_homeserver(&self) -> Result<Homeserver>

Run a Pubky Homeserver

pub async fn run_homeserver_with_signup_tokens(&self) -> Result<Homeserver>

Run a Pubky Homeserver that requires signup tokens

pub async fn run_http_relay(&self) -> Result<HttpRelay>

Run an HTTP Relay

pub fn client_builder(&self) -> ClientBuilder

Create a ClientBuilder and configure it to use this local test network.

pub async fn run_pkarr_relay(&mut self) -> Result<Url>

Run a new Pkarr relay.

You can access the list of relays at Self::relays.