pub struct Testnet { /* private fields */ }Expand description
A local test network for Pubky Core development.
Implementations
Sourceimpl Testnet
impl Testnet
Sourcepub async fn run_with_hardcoded_configurations() -> Result<Self>
pub async fn run_with_hardcoded_configurations() -> Result<Self>
Sourcepub async fn run_homeserver(&self) -> Result<Homeserver>
pub async fn run_homeserver(&self) -> Result<Homeserver>
Run a Pubky Homeserver
Sourcepub async fn run_homeserver_with_signup_tokens(&self) -> Result<Homeserver>
pub async fn run_homeserver_with_signup_tokens(&self) -> Result<Homeserver>
Run a Pubky Homeserver that requires signup tokens
Sourcepub async fn run_http_relay(&self) -> Result<HttpRelay>
pub async fn run_http_relay(&self) -> Result<HttpRelay>
Run an HTTP Relay
Sourcepub fn client_builder(&self) -> ClientBuilder
pub fn client_builder(&self) -> ClientBuilder
Create a ClientBuilder and configure it to use this local test network.
Sourcepub async fn run_pkarr_relay(&mut self) -> Result<Url>
pub async fn run_pkarr_relay(&mut self) -> Result<Url>
Run a new Pkarr relay.
You can access the list of relays at Self::relays.